==> nomachine-8.8.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/Common/NXImage.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub Common::NXImage::import{package Common::NXImage;no warnings;(my $source=
shift (@_));(my $destination=shift (@_));(my $tempDestination=($destination.
"\x2e\x70\x61\x72\x74"));if ((__import ($source,$tempDestination)<
(0x0c8c+ 1022-0x108a))){return ((0x0af7+ 3232-0x1797));}if ((not (rename (
$tempDestination,$destination)))){Logger::warning (((((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6e\x61\x6d\x65\x20\x66\x69\x6c\x65\x20\x27"
.$tempDestination)."\x27\x20\x74\x6f\x20\x27").$destination).
"\x27\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x20").$!)."\x2e"));if ((not (
unlink ($tempDestination)))){Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x75\x6e\x6c\x69\x6e\x6b\x20\x66\x69\x6c\x65\x20".
$tempDestination)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$!)."\x2e"));}
return ((0x12dc+ 2683-0x1d57));}return ((0x050a+ 3330-0x120b));}sub 
Common::NXImage::delete{package Common::NXImage;no warnings;(my $path=shift (@_)
);Logger::debug (((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x44\x65\x6c\x65\x74\x65\x28"
.$path)."\x29"));(my $return=libnxhc::NXImageDelete ($path));Logger::debug ((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x44\x65\x6c\x65\x74\x65\x28"
.$path)."\x29\x20\x72\x65\x74\x75\x72\x6e\x20").$return));if (($return<
(0x0380+ 4596-0x1574))){(my $errorNumber=libnxh::NXShellGetError ());(my $errorString
=libnxh::NXGetSystemErrorString ($errorNumber));Logger::warning (((((
"\x43\x6f\x75\x6c\x64\x6e\x27\x74\x20\x64\x65\x6c\x65\x74\x65\x20\x69\x6d\x61\x67\x65\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20").$errorString)."\x2e"));}return ($return);}sub 
Common::NXImage::list{package Common::NXImage;no warnings;(my $path=shift (@_));
Logger::debug (((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x4c\x69\x73\x74\x28"
.$path)."\x29"));(my $buffer=libnxhc::NXImageList ($path));Logger::debug ((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x4c\x69\x73\x74\x28"
.$path)."\x29\x20\x72\x65\x74\x75\x72\x6e\x20").$buffer));(my (@files)=());if (
defined ($buffer)){(@files=split ( /\n/ ,$buffer,(0x0332+ 2059-0x0b3d)));}return
 (@files);}sub Common::NXImage::isoCreate{package Common::NXImage;no warnings;(my $output
=shift (@_));(my $input=shift (@_));(my $label=shift (@_));(my $joliet=shift (@_
));Logger::debug (((((((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x73\x6f\x43\x72\x65\x61\x74\x65\x28"
.$output)."\x2c\x20").$input)."\x2c\x20").$label)."\x2c\x20").$joliet)."\x29"));
(my $return=libnxhc::NXIsoCreate ($output,$input,$label,$joliet));Logger::debug 
(((((((((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x73\x6f\x43\x72\x65\x61\x74\x65\x28"
.$output)."\x2c\x20").$input)."\x2c\x20").$label)."\x2c\x20").$joliet).
"\x29\x20\x72\x65\x74\x75\x72\x6e\x20").$return)."\x2e"));if (($return==
(0x0404+ 389-0x0589))){(my $errorNumber=NXPL::NXShellGetError ());(my $errorString
=NXPL::NXGetSystemErrorString ($errorNumber));Logger::error (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x63\x72\x65\x61\x74\x65\x20\x49\x53\x4f\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20").$errorString)."\x2e"));}return ($return);}sub 
Common::NXImage::replace{package Common::NXImage;no warnings;(my $source=shift (
@_));(my $destination=shift (@_));(my $tempDestination=($destination.
"\x2e\x70\x61\x72\x74"));if ((__import ($source,$tempDestination)<
(0x0af1+ 4870-0x1df7))){return ((0x087c+ 3579-0x1677));}if ((not (unlink (
$destination)))){Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x75\x6e\x6c\x69\x6e\x6b\x20\x66\x69\x6c\x65\x20".
$destination)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$!)."\x2e"));if ((
not (unlink ($tempDestination)))){Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x75\x6e\x6c\x69\x6e\x6b\x20\x66\x69\x6c\x65\x20".
$tempDestination)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$!)."\x2e"));}
return ((0x04f3+ 206-0x05c1));}if ((not (rename ($tempDestination,$destination))
)){Logger::warning (((((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6e\x61\x6d\x65\x20\x66\x69\x6c\x65\x20\x27"
.$tempDestination)."\x27\x20\x74\x6f\x20\x27").$destination).
"\x27\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x20").$!)."\x2e"));if ((not (
unlink ($tempDestination)))){Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x75\x6e\x6c\x69\x6e\x6b\x20\x66\x69\x6c\x65\x20".
$tempDestination)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$!)."\x2e"));}
return ((0x008f+ 3647-0x0ece));}return ((0x077f+ 4686-0x19cc));}sub 
Common::NXImage::__import{package Common::NXImage;no warnings;(my $source=shift 
(@_));(my $destination=shift (@_));Logger::debug (((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x49\x6d\x70\x6f\x72\x74\x28"
.$source)."\x2c\x20").$destination)."\x29"));(my $return=libnxhc::NXImageImport 
($source,$destination));Logger::debug ((((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x49\x6d\x70\x6f\x72\x74\x28"
.$source)."\x2c\x20").$destination)."\x29\x20\x72\x65\x74\x75\x72\x6e\x20").
$return));if (($return<(0x25ca+ 207-0x2699))){(my $errorNumber=
libnxh::NXShellGetError ());(my $errorString=libnxh::NXGetSystemErrorString (
$errorNumber));Logger::warning (((((
"\x43\x6f\x75\x6c\x64\x6e\x27\x74\x20\x69\x6d\x70\x6f\x72\x74\x20\x69\x6d\x61\x67\x65\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20").$errorString)."\x2e"));if (Common::NXFile::isExists (
$destination)){if ((not (unlink ($destination)))){Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x75\x6e\x6c\x69\x6e\x6b\x20\x66\x69\x6c\x65\x20".
$destination)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$!)."\x2e"));}}}
return ($return);}package Common::NXImage;no warnings;"\x3f\x3f\x3f";

==> nomachine-8.10.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/Common/NXImage.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub Common::NXImage::import{package Common::NXImage;no warnings;(my $source=
shift (@_));(my $destination=shift (@_));(my $tempDestination=($destination.
"\x2e\x70\x61\x72\x74"));if ((__import ($source,$tempDestination)<
(0x033f+ 3583-0x113e))){return ((0x0e41+ 4075-0x1e2c));}if ((not (rename (
$tempDestination,$destination)))){Logger::warning (((((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6e\x61\x6d\x65\x20\x66\x69\x6c\x65\x20\x27"
.$tempDestination)."\x27\x20\x74\x6f\x20\x27").$destination).
"\x27\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x20").$!)."\x2e"));if ((not (
unlink ($tempDestination)))){Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x75\x6e\x6c\x69\x6e\x6b\x20\x66\x69\x6c\x65\x20".
$tempDestination)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$!)."\x2e"));}
return ((0x0799+ 5598-0x1d77));}return ((0x00d5+ 7796-0x1f48));}sub 
Common::NXImage::delete{package Common::NXImage;no warnings;(my $path=shift (@_)
);Logger::debug (((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x44\x65\x6c\x65\x74\x65\x28"
.$path)."\x29"));(my $return=libnxhc::NXImageDelete ($path));Logger::debug ((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x44\x65\x6c\x65\x74\x65\x28"
.$path)."\x29\x20\x72\x65\x74\x75\x72\x6e\x20").$return));if (($return<
(0x138a+ 4005-0x232f))){(my $errorNumber=libnxh::NXShellGetError ());(my $errorString
=libnxh::NXGetSystemErrorString ($errorNumber));Logger::warning (((((
"\x43\x6f\x75\x6c\x64\x6e\x27\x74\x20\x64\x65\x6c\x65\x74\x65\x20\x69\x6d\x61\x67\x65\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20").$errorString)."\x2e"));}return ($return);}sub 
Common::NXImage::list{package Common::NXImage;no warnings;(my $path=shift (@_));
Logger::debug (((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x4c\x69\x73\x74\x28"
.$path)."\x29"));(my $buffer=libnxhc::NXImageList ($path));Logger::debug ((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x4c\x69\x73\x74\x28"
.$path)."\x29\x20\x72\x65\x74\x75\x72\x6e\x20").$buffer));(my (@files)=());if (
defined ($buffer)){(@files=split ( /\n/ ,$buffer,(0x066b+ 7506-0x23bd)));}return
 (@files);}sub Common::NXImage::isoCreate{package Common::NXImage;no warnings;(my $output
=shift (@_));(my $input=shift (@_));(my $label=shift (@_));(my $joliet=shift (@_
));Logger::debug (((((((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x73\x6f\x43\x72\x65\x61\x74\x65\x28"
.$output)."\x2c\x20").$input)."\x2c\x20").$label)."\x2c\x20").$joliet)."\x29"));
(my $return=libnxhc::NXIsoCreate ($output,$input,$label,$joliet));Logger::debug 
(((((((((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x73\x6f\x43\x72\x65\x61\x74\x65\x28"
.$output)."\x2c\x20").$input)."\x2c\x20").$label)."\x2c\x20").$joliet).
"\x29\x20\x72\x65\x74\x75\x72\x6e\x20").$return)."\x2e"));if (($return==
(0x0fb3+ 3255-0x1c6a))){(my $errorNumber=NXPL::NXShellGetError ());(my $errorString
=NXPL::NXGetSystemErrorString ($errorNumber));Logger::error (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x63\x72\x65\x61\x74\x65\x20\x49\x53\x4f\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20").$errorString)."\x2e"));}return ($return);}sub 
Common::NXImage::replace{package Common::NXImage;no warnings;(my $source=shift (
@_));(my $destination=shift (@_));(my $tempDestination=($destination.
"\x2e\x70\x61\x72\x74"));if ((__import ($source,$tempDestination)<
(0x1cba+ 862-0x2018))){return ((0x0794+ 6881-0x2275));}if ((not (unlink (
$destination)))){Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x75\x6e\x6c\x69\x6e\x6b\x20\x66\x69\x6c\x65\x20".
$destination)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$!)."\x2e"));if ((
not (unlink ($tempDestination)))){Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x75\x6e\x6c\x69\x6e\x6b\x20\x66\x69\x6c\x65\x20".
$tempDestination)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$!)."\x2e"));}
return ((0x146b+ 2680-0x1ee3));}if ((not (rename ($tempDestination,$destination)
))){Logger::warning (((((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6e\x61\x6d\x65\x20\x66\x69\x6c\x65\x20\x27"
.$tempDestination)."\x27\x20\x74\x6f\x20\x27").$destination).
"\x27\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x20").$!)."\x2e"));if ((not (
unlink ($tempDestination)))){Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x75\x6e\x6c\x69\x6e\x6b\x20\x66\x69\x6c\x65\x20".
$tempDestination)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$!)."\x2e"));}
return ((0x05d7+ 6462-0x1f15));}return ((0x0de9+ 4087-0x1ddf));}sub 
Common::NXImage::__import{package Common::NXImage;no warnings;(my $source=shift 
(@_));(my $destination=shift (@_));Logger::debug (((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x49\x6d\x70\x6f\x72\x74\x28"
.$source)."\x2c\x20").$destination)."\x29"));(my $return=libnxhc::NXImageImport 
($source,$destination));Logger::debug ((((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x49\x6d\x70\x6f\x72\x74\x28"
.$source)."\x2c\x20").$destination)."\x29\x20\x72\x65\x74\x75\x72\x6e\x20").
$return));if (($return<(0x040c+ 2456-0x0da4))){(my $errorNumber=
libnxh::NXShellGetError ());(my $errorString=libnxh::NXGetSystemErrorString (
$errorNumber));Logger::warning (((((
"\x43\x6f\x75\x6c\x64\x6e\x27\x74\x20\x69\x6d\x70\x6f\x72\x74\x20\x69\x6d\x61\x67\x65\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20").$errorString)."\x2e"));if (Common::NXFile::isExists (
$destination)){if ((not (unlink ($destination)))){Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x75\x6e\x6c\x69\x6e\x6b\x20\x66\x69\x6c\x65\x20".
$destination)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$!)."\x2e"));}}}
return ($return);}package Common::NXImage;no warnings;"\x3f\x3f\x3f";
